package com.sun.java.swing.plaf.motif;

import java.awt.Dimension;
import java.awt.Insets;
import java.awt.Shape;
import javax.swing.SwingUtilities;
import javax.swing.border.AbstractBorder;
import java.awt.Rectangle;
import java.awt.Graphics;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;
import javax.swing.plaf.basic.BasicButtonListener;
import javax.swing.AbstractButton;
import sun.awt.AppContext;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Color;
import javax.swing.plaf.basic.BasicButtonUI;

public class MotifButtonUI extends BasicButtonUI
{
    protected Color selectColor;
    private boolean defaults_initialized;
    private static final Object MOTIF_BUTTON_UI_KEY;
    
    public MotifButtonUI() {
        this.defaults_initialized = false;
    }
    
    public static ComponentUI createUI(JComponent component) {
        AppContext appContext = AppContext.getAppContext();
        MotifButtonUI value = (MotifButtonUI)appContext.get(MotifButtonUI.MOTIF_BUTTON_UI_KEY);
        if (value == null) {
            value = new MotifButtonUI();
            appContext.put(MotifButtonUI.MOTIF_BUTTON_UI_KEY, value);
            return value;
        }
        return value;
    }
    
    @Override
    protected BasicButtonListener createButtonListener(AbstractButton abstractButton) {
        return new MotifButtonListener(abstractButton);
    }
    
    public void installDefaults(AbstractButton abstractButton) {
        super.installDefaults(abstractButton);
        if (!this.defaults_initialized) {
            this.selectColor = UIManager.getColor(this.getPropertyPrefix() + "select");
            this.defaults_initialized = true;
        }
        LookAndFeel.installProperty(abstractButton, "opaque", Boolean.FALSE);
    }
    
    @Override
    protected void uninstallDefaults(AbstractButton b) {
        super.uninstallDefaults(b);
        this.defaults_initialized = false;
    }
    
    protected Color getSelectColor() {
        return this.selectColor;
    }
    
    @Override
    public void paint(Graphics g, JComponent c) {
        this.fillContentArea(g, (AbstractButton)c, c.getBackground());
        super.paint(g, c);
    }
    
    @Override
    protected void paintIcon(Graphics g, JComponent component, Rectangle iconRect) {
        Shape clip = g.getClip();
        Rectangle interiorRectangle = AbstractBorder.getInteriorRectangle(component, component.getBorder(), 0, 0, component.getWidth(), component.getHeight());
        Rectangle bounds = clip.getBounds();
        g.setClip(SwingUtilities.computeIntersection(bounds.x, bounds.y, bounds.width, bounds.height, interiorRectangle));
        super.paintIcon(g, component, iconRect);
        g.setClip(clip);
    }
    
    @Override
    protected void paintFocus(Graphics graphics, AbstractButton abstractButton, Rectangle rectangle, Rectangle rectangle2, Rectangle rectangle3) {
    }
    
    @Override
    protected void paintButtonPressed(Graphics graphics, AbstractButton abstractButton) {
        this.fillContentArea(graphics, abstractButton, this.selectColor);
    }
    
    protected void fillContentArea(Graphics graphics, AbstractButton abstractButton, Color color) {
        if (abstractButton.isContentAreaFilled()) {
            Insets margin = abstractButton.getMargin();
            Insets insets = abstractButton.getInsets();
            Dimension size = abstractButton.getSize();
            graphics.setColor(color);
            graphics.fillRect(insets.left - margin.left, insets.top - margin.top, size.width - (insets.left - margin.left) - (insets.right - margin.right), size.height - (insets.top - margin.top) - (insets.bottom - margin.bottom));
        }
    }
    
    static {
        MOTIF_BUTTON_UI_KEY = new Object();
    }
}
